# ELibs

ELibs is a Python library for dealing with tomticket api.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install elibs.

```bash
pip install elibs
```

## Usage

```python
import elibs

tt = elibs.TomTicket(API_TOKEN)

print(tt.get_clientes())
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.


## License
[MIT](https://choosealicense.com/licenses/mit/)
